StreamMuxer class

Represents a stream multiplexer with its protocol ID and factory function

Constructors

StreamMuxer({required String id, required Multiplexer muxerFactory(Conn secureConn, bool isClient)})
Creates a new StreamMuxer
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
The protocol ID for this multiplexer (e.g., '/yamux/1.0.0')
final
muxerFactory → Multiplexer Function(Conn secureConn, bool isClient)
Factory function to create a new multiplexer instance. The 'secureConn' is the connection after security protocols have been applied. The 'isClient' flag indicates if this node is the client in the connection setup.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited