Ed25519PrivateKey class

Implementation of Ed25519 private key

Implemented types

Constructors

Ed25519PrivateKey.withPublicKey(SimpleKeyPair _keyPair, Ed25519PublicKey _publicKey, [Uint8List? _privateKeyBytes])
Creates an Ed25519PrivateKey with a public key

Properties

hashCode → int
The hash code for this object.
no setterinherited
publicKey → PublicKey
Gets the public key corresponding to this private key
no setteroverride
raw → Uint8List
Returns the key's raw bytes
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → KeyType
Returns the key's type
no setteroverride

Methods

equals(PrivateKey other) → Future<bool>
Checks if this private key is equal to another
override
marshal() → Uint8List
Returns the protobuf bytes of the key
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(Uint8List data) → Future<Uint8List>
Signs the given data
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create(SimpleKeyPair keyPair, [Uint8List? privateKeyBytes]) → Future<Ed25519PrivateKey>
Factory constructor that initializes the public key
fromRawBytes(Uint8List bytes) → Future<Ed25519PrivateKey>
Creates an Ed25519PrivateKey from raw bytes
generateKeyPair() → Future<KeyPair>
Generate a new Ed25519 key pair
generateKeyPairFromSeed(Uint8List seed) → Future<KeyPair>
Generate a new Ed25519 key pair
unmarshal(Uint8List bytes) → Future<PrivateKey>
Creates an Ed25519PrivateKey from its protobuf bytes