DiscoveryOptions class

Options for discovery operations

Constructors

DiscoveryOptions({Duration? ttl, int? limit, Map? other})
Creates a new DiscoveryOptions

Properties

hashCode → int
The hash code for this object.
no setterinherited
limit → int?
Maximum number of peers to discover
final
other → Map
Other implementation-specific options
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ttl → Duration?
Time-to-live for advertisements
final

Methods

apply(List<DiscoveryOption> options) → DiscoveryOptions
Applies the given options to this DiscoveryOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited