EventBus class abstract

Bus is an interface for a type-based event delivery system.

Implementers

Constructors

EventBus()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

emitter(dynamic eventType, {List<EmitterOpt>? opts}) → Future<Emitter>
Creates a new event emitter.
getAllEventTypes() → List<String>
Returns all the event types that this bus knows about (having emitters and subscribers). It omits the WildcardSubscription.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subscribe(Object eventType, {List<EmitterOpt>? opts}) → Subscription
Subscribe creates a new Subscription.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited