EvtPeerIdentificationCompleted class

EvtPeerIdentificationCompleted is emitted when the initial identification round for a peer is completed.

Constructors

EvtPeerIdentificationCompleted({required PeerId peer, required Conn conn, required List<MultiAddr> listenAddrs, required List<ProtocolID> protocols, dynamic signedPeerRecord, required String agentVersion, required String protocolVersion, MultiAddr? observedAddr})
Creates a new EvtPeerIdentificationCompleted event.

Properties

agentVersion → String
AgentVersion is like a UserAgent string in browsers, or client version in bittorrent includes the client name and client.
final
conn → Conn
Conn is the connection we identified.
final
hashCode → int
The hash code for this object.
no setterinherited
listenAddrs → List<MultiAddr>
ListenAddrs is the list of addresses the peer is listening on.
final
observedAddr → MultiAddr?
ObservedAddr is the our side's connection address as observed by the peer. This is not verified, the peer could return anything here.
final
peer → PeerId
Peer is the ID of the peer whose identification succeeded.
final
protocols → List<ProtocolID>
Protocols is the list of protocols the peer advertised on this connection.
final
protocolVersion → String
ProtocolVersion is the protocolVersion field in the identify message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signedPeerRecord → dynamic
SignedPeerRecord is the provided signed peer record of the peer. May be null.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited