EvtPeerIdentificationFailed class

EvtPeerIdentificationFailed is emitted when the initial identification round for a peer failed.

Constructors

EvtPeerIdentificationFailed({required PeerId peer, required Exception reason})
Creates a new EvtPeerIdentificationFailed event.

Properties

hashCode → int
The hash code for this object.
no setterinherited
peer → PeerId
Peer is the ID of the peer whose identification failed.
final
reason → Exception
Reason is the reason why identification failed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited