Conn class abstract

Conn is a connection to a remote peer. It multiplexes streams. Usually there is no need to use a Conn directly, but it may be useful to get information about the peer on the other side:

stream.Conn().RemotePeer()

Implementers

Constructors

Conn()

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
ID returns an identifier that uniquely identifies this Conn within this host, during this run. Connection IDs may repeat across restarts.
no setter
isClosed → bool
IsClosed returns whether a connection is fully closed, so it can be garbage collected.
no setter
localMultiaddr → MultiAddr
LocalMultiaddr returns the local Multiaddr associated with this connection
no setter
localPeer → PeerId
LocalPeer returns our peer ID
no setter
remoteMultiaddr → MultiAddr
RemoteMultiaddr returns the remote Multiaddr associated with this connection
no setter
remotePeer → PeerId
RemotePeer returns the peer ID of the remote peer.
no setter
remotePublicKey → Future<PublicKey?>
RemotePublicKey returns the public key of the remote peer.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → ConnScope
Scope returns the user view of this connection's resource scope
no setter
stat → ConnStats
Stat stores metadata pertaining to this conn.
no setter
state → ConnState
ConnState returns information about the connection state.
no setter
streams → Future<List<P2PStream>>
GetStreams returns all open streams over this conn.
no setter

Methods

close() → Future<void>
Closes the connection
newStream(Context context) → Future<P2PStream>
NewStream constructs a new Stream over this conn.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited