Multiplexer class abstract

Multiplexer wraps a connection with a stream multiplexing implementation and returns a MuxedConn that supports opening multiple streams over the underlying connection

Constructors

Multiplexer()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

newConn(Socket conn, bool isServer, PeerScope scope) → Future<MuxedConn>
Constructs a new connection
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited