MuxedConn class abstract

MuxedConn represents a connection to a remote peer that has been extended to support stream multiplexing.

A MuxedConn allows a single connection to carry many logically independent bidirectional streams of binary data.

Together with network.ConnSecurity, MuxedConn is a component of the transport.CapableConn interface, which represents a "raw" network connection that has been "upgraded" to support the libp2p capabilities of secure communication and stream multiplexing.

Implementers

Constructors

MuxedConn()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isClosed → bool
Returns whether a connection is fully closed, so it can be garbage collected.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptStream() → Future<MuxedStream>
Accepts a stream opened by the other side.
close() → Future<void>
Closes the stream muxer and the the underlying connection.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openStream(Context context) → Future<MuxedStream>
Creates a new stream.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited