setDeadline abstract method
Sets a deadline for all operations on the stream.
Passing null clears any previously set deadline.
Implementation
void setDeadline(DateTime? time);
Sets a deadline for all operations on the stream.
Passing null clears any previously set deadline.
void setDeadline(DateTime? time);