Dialer class abstract

Dialer represents a service that can dial out to peers

Implementers

Constructors

Dialer()

Properties

conns → List<Conn>
Returns the connections in this Network
no setter
hashCode → int
The hash code for this object.
no setterinherited
localPeer → PeerId
Returns the local peer associated with this network
no setter
peers → List<PeerId>
Returns the peers connected
no setter
peerstore → Peerstore
Returns the internal peerstore This is useful to tell the dialer about a new address for a peer. Or use one of the public keys found out over the network.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canDial(PeerId peerId, MultiAddr addr) → bool
Returns whether the dialer can dial peer p at addr
closePeer(PeerId peerId) → Future<void>
Closes the connection to a given peer
connectedness(PeerId peerId) → Connectedness
Returns a state signaling connection capabilities
connsToPeer(PeerId peerId) → List<Conn>
Returns the connections in this Network for given peer.
dialPeer(Context context, PeerId peerId) → Future<Conn>
Establishes a connection to a given peer
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify(Notifiee notifiee) → void
Register a notifiee for signals
removeListenAddress(MultiAddr addr) → void
stopNotify(Notifiee notifiee) → void
Unregister a notifiee for signals
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited