EvtPeerConnectednessChanged class

Constructors

EvtPeerConnectednessChanged({required PeerId peer, required Connectedness connectedness})
Creates a new EvtPeerConnectednessChanged event.

Properties

connectedness → Connectedness
Connectedness is the new connectedness state.
final
hashCode → int
The hash code for this object.
no setterinherited
peer → PeerId
Peer is the remote peer whose connectedness has changed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited