core/network/notifiee library

Classes

NoopNotifiee
NoopNotifiee is a no-op implementation of Notifiee
Notifiee
Notifiee is an interface for an object wishing to receive notifications from a Network.
NotifyBundle
NotifyBundle implements Notifiee by calling any of the functions set on it, and nop'ing if they are unset. This is the easy way to register for notifications.

Properties

globalNoopNotifiee → NoopNotifiee
Global noop notifiee. Do not change.
final