recentlyConnectedAddrTTL constant

Duration const recentlyConnectedAddrTTL

Used when we recently connected to a peer. It means that we are reasonably certain of the peer's address. Increased to 4 hours to support persistent connections and prevent premature address expiration for gossipsub mesh and DHT routing peers.

Implementation

static const Duration recentlyConnectedAddrTTL = Duration(hours: 4);