PeerStoreConfig class

Configuration for the peer store

Constructors

PeerStoreConfig({int maxPeers = 1000, Duration peerTTL = const Duration(hours: 24), Duration cleanupInterval = const Duration(minutes: 30)})
const

Properties

cleanupInterval → Duration
How often to clean up expired peers
final
hashCode → int
The hash code for this object.
no setterinherited
maxPeers → int
The maximum number of peers to store
final
peerTTL → Duration
How long to keep peer records without updates
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited