core/record/pb/envelope.pb library
Classes
- Envelope
- Envelope encloses a signed payload produced by a peer, along with the public key of the keypair it was signed with so that it can be statelessly validated by the receiver.
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.