RoutingOptions class

Options for routing operations.

Constructors

RoutingOptions()

Properties

expired ↔ bool
Allow expired values.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
offline ↔ bool
Operate in offline mode (rely on cached/local data only).
getter/setter pair
other ↔ Map?
Other (ValueStore implementation specific) options.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(List<Option> options) → void
Apply the given options to this Options instance.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toOption() → Option
Convert this Options to a single Option function.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited