BackoffStrategy class abstract

Describes how backoff will be implemented. BackoffStrategies are stateful.

Implementers

Constructors

BackoffStrategy()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delay() → Duration
Calculates how long the next backoff duration should be, given the prior calls to delay
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
Clears the internal state of the BackoffStrategy
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited