ExponentialBackoff class

A backoff strategy based on an exponential function of the attempt number

Implemented types

Constructors

ExponentialBackoff(AttemptBackoff attemptBackoff, Duration timeUnits, double base, Duration offset)

Properties

attemptBackoff → AttemptBackoff
final
base → double
final
hashCode → int
The hash code for this object.
no setterinherited
offset → Duration
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeUnits → Duration
final

Methods

delay() → Duration
Calculates how long the next backoff duration should be, given the prior calls to delay
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
Clears the internal state of the BackoffStrategy
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited