FixedBackoff class

A backoff strategy with a constant delay

Implemented types

Constructors

FixedBackoff(Duration delay_)

Properties

delay_ → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delay() → Duration
Calculates how long the next backoff duration should be, given the prior calls to delay
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
Clears the internal state of the BackoffStrategy
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited