BackoffCache class

Cache for peer information with backoff

Constructors

BackoffCache(BackoffStrategy strat, Clock clock)

Properties

clock → Clock
final
hashCode → int
The hash code for this object.
no setterinherited
nextDiscover ↔ DateTime
getter/setter pair
ongoing ↔ bool
getter/setter pair
peers ↔ Map<PeerId, AddrInfo>
getter/setter pair
prevPeers ↔ Map<PeerId, AddrInfo>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendingChs ↔ Map<StreamController<AddrInfo>, int?>
getter/setter pair
strat → BackoffStrategy
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited