OutboundCapabilityInfo class
Information about local outbound connectivity capabilities
Constructors
- OutboundCapabilityInfo({required bool hasIPv4, required bool hasIPv6, required DateTime detectedAt})
Properties
- capability → OutboundCapability
-
no setter
- detectedAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasIPv4 → bool
-
final
- hasIPv6 → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited