BaseLimit class

BaseLimit provides a concrete implementation of the Limit interface.

Implemented types

Constructors

BaseLimit({int streams = 0, int streamsInbound = 0, int streamsOutbound = 0, int conns = 0, int connsInbound = 0, int connsOutbound = 0, int fd = 0, int memory = 0})

Properties

conns → int
final
connsInbound → int
final
connsOutbound → int
final
connTotalLimit → int
GetConnTotalLimit returns the total connection limit.
no setteroverride
fd → int
final
fdLimit → int
GetFDLimit returns the file descriptor limit. For Dart, this might be conceptual (e.g., number of active connections) or ignored if not directly applicable.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
memory → int
final
memoryLimit → int
GetMemoryLimit returns the (current) memory limit in bytes.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streams → int
final
streamsInbound → int
final
streamsOutbound → int
final
streamTotalLimit → int
GetStreamTotalLimit returns the total stream limit.
no setteroverride

Methods

apply(BaseLimit other) → BaseLimit
Creates a new BaseLimit by applying values from other for any fields that are zero in this limit.
getConnLimit(Direction direction) → int
GetConnLimit returns the connection limit, for inbound or outbound connections.
override
getStreamLimit(Direction direction) → int
GetStreamLimit returns the stream limit, for inbound or outbound streams.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

blockAll() → BaseLimit
unlimited() → BaseLimit