Limit class abstract

Limit is an object that specifies basic resource limits.

Implementers

Constructors

Limit()

Properties

connTotalLimit → int
GetConnTotalLimit returns the total connection limit.
no setter
fdLimit → int
GetFDLimit returns the file descriptor limit. For Dart, this might be conceptual (e.g., number of active connections) or ignored if not directly applicable.
no setter
hashCode → int
The hash code for this object.
no setterinherited
memoryLimit → int
GetMemoryLimit returns the (current) memory limit in bytes.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamTotalLimit → int
GetStreamTotalLimit returns the total stream limit.
no setter

Methods

getConnLimit(Direction direction) → int
GetConnLimit returns the connection limit, for inbound or outbound connections.
getStreamLimit(Direction direction) → int
GetStreamLimit returns the stream limit, for inbound or outbound streams.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited