Limiter class abstract

Limiter is the interface for providing limits to the resource manager.

Implementers

Constructors

Limiter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllowlistedSystemLimits() → Limit
getAllowlistedTransientLimits() → Limit
getConnLimits() → Limit
getPeerLimits(PeerId peer) → Limit
getProtocolLimits(ProtocolID protocol) → Limit
getProtocolPeerLimits(ProtocolID protocol, PeerId peer) → Limit
getServiceLimits(String service) → Limit
getServicePeerLimits(String service, PeerId peer) → Limit
getStreamLimits(PeerId peer) → Limit
getSystemLimits() → Limit
getTransientLimits() → Limit
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited