NatBehavior class

Comprehensive NAT behavior information

Constructors

NatBehavior({NatMappingBehavior mappingBehavior = NatMappingBehavior.unknown, NatFilteringBehavior filteringBehavior = NatFilteringBehavior.unknown, bool? supportsHairpinning, bool? preservesPorts, bool? supportsPortMapping, int? mappingLifetime})

Properties

filteringBehavior → NatFilteringBehavior
The NAT filtering behavior
final
hashCode → int
The hash code for this object.
no setterinherited
mappingBehavior → NatMappingBehavior
The NAT mapping behavior
final
mappingLifetime → int?
The mapping lifetime in seconds (if known)
final
preservesPorts → bool?
Whether the NAT preserves ports
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsHairpinning → bool?
Whether hairpinning is supported
final
supportsPortMapping → bool?
Whether the NAT supports port mapping
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns a string representation of the NAT behavior
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited