NatMappingBehavior enum

Enums and classes for NAT behavior discovery as defined in RFC 5780. NAT mapping behavior as defined in RFC 5780.

This describes how a NAT maps internal endpoints to external endpoints.

Inheritance
Available extensions

Values

unknown → const NatMappingBehavior

Unknown mapping behavior (not yet determined)

endpointIndependent → const NatMappingBehavior

Endpoint-independent mapping: The NAT reuses the same external endpoint (IP address and port) for all connections from the same internal endpoint to any external endpoint.

addressDependent → const NatMappingBehavior

Address-dependent mapping: The NAT reuses the same external endpoint for connections from the same internal endpoint to the same external IP address, regardless of the external port.

addressAndPortDependent → const NatMappingBehavior

Address and port-dependent mapping: The NAT reuses the same external endpoint for connections from the same internal endpoint to the same external endpoint.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<NatMappingBehavior>
A constant List of the values in this enum, in order of their declaration.