AutoNATv2ServerImpl class

Server implementation for AutoNAT v2

Implemented types

Constructors

AutoNATv2ServerImpl(Host host, Host dialerHost, AutoNATv2Settings settings)

Properties

allowPrivateAddrs → bool
final
amplificationAttackPreventionDialWait → Duration
final
dataRequestPolicy → DataRequestPolicyFunc
final
dialerHost → Host
final
hashCode → int
The hash code for this object.
no setterinherited
host → Host
final
limiter → RateLimiter
final
metricsTracer → MetricsTracer?
final
now → DateTime Function()
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Close the server
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → void
Start the server
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

dialBackDialTimeout → const Duration
Dial-back dial timeout
dialBackMaxMsgSize → const int
Maximum dial-back message size
dialBackStreamTimeout → const Duration
Dial-back stream timeout
maxHandshakeSizeBytes → const int
Maximum handshake size in bytes
maxMsgSize → const int
Maximum message size
maxPeerAddresses → const int
Maximum number of peer addresses to inspect
minHandshakeSizeBytes → const int
Minimum handshake size in bytes (for amplification attack prevention)
streamTimeout → const Duration
Stream timeout