closeRead method

Future<void> closeRead()

Closes the read side of the relayed connection (half-close support) This signals that we won't read any more data from the remote peer.

Implementation

Future<void> closeRead() async {
  await _stream.closeRead();
}