Reservation class

Represents a reservation on a relay.

Constructors

Reservation(DateTime expire, List<MultiAddr> addrs, Uint8List? voucher, {Duration? limitDuration, BigInt? limitData})
Creates a new reservation.

Properties

addrs → List<MultiAddr>
The addresses of the relay.
final
expire → DateTime
The expiration time of the reservation.
final
hashCode → int
The hash code for this object.
no setterinherited
limitData → BigInt?
LimitData is the number of bytes that the relay will relay in each direction before resetting a relayed connection. If null, there is no limit.
final
limitDuration → Duration?
LimitDuration is the time limit for which the relay will keep a relayed connection open. If null or zero duration, there is no limit.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
voucher → Uint8List?
The raw reservation voucher bytes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited