hasRemainingData property
bool
get
hasRemainingData
Check if there are bytes remaining in the buffer
Implementation
bool get hasRemainingData => _buffer.remainingLength > 0;
Check if there are bytes remaining in the buffer
bool get hasRemainingData => _buffer.remainingLength > 0;