HttpRoute class

Route definition for HTTP-like protocol

Constructors

HttpRoute({required HttpMethod method, required String path, required HttpRequestHandler handler})

Properties

handler → HttpRequestHandler
final
hashCode → int
The hash code for this object.
no setterinherited
method → HttpMethod
final
path → String
final
pathPattern → RegExp?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

extractParams(String path) → Map<String, String>
Extract path parameters from the given path
matches(HttpMethod method, String path) → bool
Check if this route matches the given method and path
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited