p2p/protocol/identify/metrics library

Classes

LoggingMetricsTracer
A simple metrics tracer that logs metrics to the console.
MetricsTracer
MetricsTracer is an interface for collecting metrics from the identify service.
NoopMetricsTracer
A no-op implementation of MetricsTracer that doesn't collect any metrics.

Enums

IdentifyPushSupport
The support status for the identify push protocol.