ConnAdapter class

Adapter to make Conn implement ConnMultiaddrs

Implemented types

Constructors

ConnAdapter(Conn conn)

Properties

conn → Conn
final
hashCode → int
The hash code for this object.
no setteroverride
localMultiaddr → MultiAddr
no setteroverride
remoteMultiaddr → MultiAddr
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isClosed() → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override