ConnMultiaddrs class abstract

connMultiaddrs provides isClosed along with network.ConnMultiaddrs. It is easier to mock this than network.Conn

Implementers

Constructors

ConnMultiaddrs()

Properties

hashCode → int
The hash code for this object.
no setterinherited
localMultiaddr → MultiAddr
no setter
remoteMultiaddr → MultiAddr
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isClosed() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited