UnrecognizedResponseException class

ErrUnrecognizedResponse is the error returned when the muxer responds with an unexpected message.

Implemented types

Constructors

UnrecognizedResponseException({required String actual, required String expected})
const

Properties

actual → String
final
expected → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited