Handler class

A handler for a specific protocol

Constructors

Handler({required bool matchFunc(ProtocolID), required HandlerFunc handle, required ProtocolID addName})

Properties

addName → String
The protocol name this handler was registered with
final
handle → HandlerFunc
Function to handle the protocol
final
hashCode → int
The hash code for this object.
no setterinherited
matchFunc → bool Function(ProtocolID)
Function to determine if this handler matches a given protocol
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited