OBPFlags enum

OBP Control Flags

Inheritance
Available extensions

Values

none → const OBPFlags
const OBPFlags(0x00)
ackRequired → const OBPFlags
const OBPFlags(0x01)
fin → const OBPFlags
const OBPFlags(0x02)
err → const OBPFlags
const OBPFlags(0x04)
compressed → const OBPFlags
const OBPFlags(0x08)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromValue(int value) → OBPFlags

Constants

values → const List<OBPFlags>
A constant List of the values in this enum, in order of their declaration.