StompServerConnection class

Represents a client connection to the STOMP server

Constructors

StompServerConnection({required PeerId peerId, required P2PStream stream, required String sessionId, required Map<String, String> clientHeaders})

Properties

acknowledgments → StompAckManager
Acknowledgment manager for this connection
no setter
clientHeaders → Map<String, String>
final
connectedAt → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
isActive → bool
Whether the connection is active
no setter
onFrame → Stream<StompFrame>
Stream of frames from this connection
no setter
peerId → PeerId
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → String
final
state → StompServerConnectionState
Current connection state
no setter
stream → P2PStream
final
subscriptions → StompSubscriptionManager
Subscription manager for this connection
no setter
transactions → StompTransactionManager
Transaction manager for this connection
no setter

Methods

close() → Future<void>
Closes the connection
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendFrame(StompFrame frame) → Future<void>
Sends a frame to the client
setState(StompServerConnectionState newState) → void
Sets the connection state
startReading() → void
Starts reading frames from the client
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited