StompServiceStats class

Statistics about the STOMP service

Constructors

StompServiceStats({required bool isStarted, required bool serverEnabled, required bool serverRunning, required int connectedClients, required int totalClients, required int serverConnections})
const

Properties

connectedClients → int
Number of connected clients
final
hashCode → int
The hash code for this object.
no setterinherited
isStarted → bool
Whether the service is started
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverConnections → int
Number of connections to the server
final
serverEnabled → bool
Whether the server is enabled
final
serverRunning → bool
Whether the server is running
final
totalClients → int
Total number of clients (including disconnected)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited