PendingAck class

Pending acknowledgment for a message

Constructors

PendingAck({required String messageId, required String subscriptionId, required String? ackId, required StompAckMode ackMode})

Properties

ackId → String?
final
ackMode → StompAckMode
final
hashCode → int
The hash code for this object.
no setteroverride
messageId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscriptionId → String
final
timestamp → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override