StompTransactionStats class

Transaction statistics

Constructors

StompTransactionStats({required int totalTransactions, required int activeTransactions, required int committedTransactions, required int abortedTransactions, required Duration averageTransactionDuration, required Duration longestTransactionDuration})
StompTransactionStats.fromManager(StompTransactionManager manager)
Creates statistics from a transaction manager
factory

Properties

abortedTransactions → int
final
activeTransactions → int
final
averageTransactionDuration → Duration
final
committedTransactions → int
final
hashCode → int
The hash code for this object.
no setterinherited
longestTransactionDuration → Duration
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalTransactions → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited