ConnectionStateChange class

Represents a state change event in a connection

Constructors

ConnectionStateChange({required ConnectionState previousState, required ConnectionState newState, Object? error})
Creates a new connection state change event

Properties

error → Object?
Optional error that caused the state change
final
hashCode → int
The hash code for this object.
no setterinherited
newState → ConnectionState
The new state of the connection
final
previousState → ConnectionState
The previous state of the connection
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
The timestamp when the state change occurred
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited