MultiplexerConfig class

Configuration for stream multiplexing

Constructors

MultiplexerConfig({int maxStreams = 1000, int initialStreamWindowSize = 256 * 1024, int maxStreamWindowSize = 16 * 1024 * 1024, int maxFrameSize = 16 * 1024, Duration streamReadTimeout = const Duration(seconds: 30), Duration streamWriteTimeout = const Duration(seconds: 30), Duration keepAliveInterval = const Duration(seconds: 10), Duration connectionReadTimeout = const Duration(seconds: 35)})
const

Properties

connectionReadTimeout Duration
Connection-level read timeout for idle connections (default: 35 seconds) This should be at least 3x the keepAliveInterval to allow for keepalive pings before timing out an idle connection.
final
hashCode int
The hash code for this object.
no setterinherited
initialStreamWindowSize int
Initial stream window size in bytes (default: 256KB)
final
keepAliveInterval Duration
Keep-alive interval (default: 10 seconds)
final
maxFrameSize int
Maximum size of a single DATA frame payload in bytes (default: 16KB)
final
maxStreams int
Maximum number of concurrent streams (default: 1000)
final
maxStreamWindowSize int
Maximum stream window size in bytes (default: 16MB)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamReadTimeout Duration
Stream read timeout (default: 30 seconds)
final
streamWriteTimeout Duration
Stream write timeout (default: 30 seconds)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited