closeWrite method
Closes the write side of the relayed connection (half-close support) This allows the remote peer to finish sending data while signaling that we won't send any more data.
Implementation
Future<void> closeWrite() async {
await _stream.closeWrite();
}